@@ -10,11 +10,11 @@ set -e
 
 version="$1"
 
-BRANCH="$(git rev-parse --abbrev-ref HEAD)"
-if [[ "$BRANCH" != "master" ]]; then
-  echo 'The release script should only be run on the master branch. Aborting...';
-  exit 1;
-fi
+#BRANCH="$(git rev-parse --abbrev-ref HEAD)"
+#if [[ "$BRANCH" != "master" ]]; then
+#  echo 'The release script should only be run on the master branch. Aborting...';
+#  exit 1;
+#fi
 
 echo "Creating release for $version"
 
